%% LaTeX template class for technical report
%% for subject NRP in Czech Technical University in Prague (CTU)
%%
%% (c) 2008-2009 Vit Zyka
%%
%% History:
%% 0.1  2008-09-21 new
%% 0.2  2008-11-12 href for email, unicode in hyperref; tolerance; microtype; cmap
%%   \texorpdfstring
%% 0.21 2008-11-24 plainnat bst style
%% 0.30 2009-09-18 \aff definition; Thermes font; bst style plain-vz-online?
%% 0.31 2009-09-29 getting more compact
%% 0.32 2009-09-30 \suppressfloats[t]
%% 0.33 2009-11-09 natbib not use
%% 0.40 2009-11-15 caption formating to full wide; slovak option
%% 0.41 2009-11-30 fix caption labels for czech and slovac

\typeout{Class nrp-report v0.41, 2009-11-30, Vit Zyka}

%% Options...
\newif\ifCzech
\newif\ifSlovak

\DeclareOption{czech}{\Czechtrue}
\DeclareOption{slovak}{\Slovaktrue}
\ProcessOptions

%\LoadClass[a4paper,normalheadings]{scrartcl}
\LoadClass[10pt,a4paper,smallheadings]{scrartcl}

%% Dimensions...
\setlength{\columnsep}{8mm}

\renewcommand{\topfraction}{0.9}
\renewcommand{\bottomfraction}{0.9}
\renewcommand{\dbltopfraction}{0.9}
\renewcommand{\textfraction}{0}
\setcounter{topnumber}{4}
\setcounter{bottomnumber}{4}
\setcounter{totalnumber}{4}
\setcounter{dbltopnumber}{4}

\tolerance=300

%% Packages...
\RequirePackage{ifpdf}
\ifCzech
  \RequirePackage[czech,english]{babel}
\fi
\ifSlovak
  \RequirePackage[slovak,english]{babel}
\fi
\RequirePackage{cmap}
\usepackage[T1]{fontenc}
% Latin Modern
%\RequirePackage{lmodern}
% Thermes, Heros, Cursor (Gyre)
\renewcommand{\rmdefault}{qtm}
\renewcommand{\sfdefault}{qhv}
\renewcommand{\ttdefault}{qcr}
% Times
%\RequirePackage{times}

\usepackage[left=14mm,right=14mm,top=18mm,bottom=20mm,footskip=10mm]{geometry}
\ifpdf
  \RequirePackage[pdftex]{graphicx}
  \RequirePackage[pdftex]{color}
\else
  \RequirePackage{graphicx}
  \RequirePackage{color}
\fi
\RequirePackage[pdfpagemode=UseNone,pdfborder=0 0 0,unicode]{hyperref}
\RequirePackage{mflogo}
%\RequirePackage{natbib}
\RequirePackage{microtype}

%% Title...
\newtoks\NRPemail        \def\email#1{\NRPemail={#1}}
\newtoks\NRPaffiliation  \def\affiliation#1{\NRPaffiliation={#1}}

\def\affiliationFont{\normalfont\fontsize{12pt}{14pt}\selectfont}

\AtBeginDocument{%
  \expandafter\author\expandafter{%
    \@author\\[4pt]\affiliationFont
    \def\\{\crcr\affiliationFont}\the\NRPaffiliation\\
    \href{mailto:\the\NRPemail}{\affiliationFont\the\NRPemail}}%
  \expandafter\date\expandafter{\expandafter\affiliationFont\@date}%
}

\def\aff#1{$^{#1}$}

\let\maketitleOrig=\maketitle
\def\maketitle{\@ifnextchar[{\domaketitle}{\domaketitle[]}}
\def\domaketitle[#1]{%
  \twocolumn[\vskip-1.5cm\maketitleOrig\begin{quotation}#1\end{quotation}\bigskip]%
  \suppressfloats[t]%
}

\def\titlefont{\sectfont\let\huge=\LARGE}

%% Sections
\renewcommand\section{\@startsection{section}{1}{\z@}%
  {-2.5ex \@plus -1ex \@minus -.2ex}%{-3.5ex \@plus -1ex \@minus -.2ex}%
  {1.0ex \@plus.2ex}%{2.3ex \@plus.2ex}%
  {\raggedsection\normalfont\sectfont\nobreak\size@section\nobreak}%
}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
  {-2.0ex\@plus -1ex \@minus -.2ex}%{-3.25ex\@plus -1ex \@minus -.2ex}%
  {0.5ex \@plus .2ex}%{1.5ex \@plus .2ex}%
  {\raggedsection\normalfont\sectfont\nobreak\size@subsection\nobreak
  }%
}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
  {-2.0ex\@plus -1ex \@minus -.2ex}%{-3.25ex\@plus -1ex \@minus -.2ex}%
  {0.5ex \@plus .2ex}%{1.5ex \@plus .2ex}%
  {\raggedsection\normalfont\sectfont\nobreak\size@subsubsection
    \nobreak
  }%
}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
  {3.25ex \@plus1ex \@minus.2ex}%
  {-1em}%
  {\raggedsection\normalfont\sectfont\nobreak\size@paragraph\nobreak}%
}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
  {3.25ex \@plus1ex \@minus .2ex}%
  {-1em}%
  {\raggedsection\normalfont\sectfont\nobreak\size@subparagraph
    \nobreak
  }%
}

%% Tables, Figures
\setcounter{totalnumber}{5} % was 3
\addtokomafont{captionlabel}{\sffamily\bfseries\small}
\addtokomafont{caption}{\it}
\setcapindent{0pt}

\AtBeginDocument{
  \def\tablename{Tab.}
  \def\figurename{Fig.}
}
\ifSlovak
  \AtBeginDocument{
    \def\tablename{Tab.}
    \def\figurename{Obr.}
  }
\fi
\ifCzech
  \AtBeginDocument{
    \def\tablename{Tab.}
    \def\figurename{Obr.}
  }
\fi

%% Bibliography...
%\bibliographystyle{plainnat}
\bibliographystyle{plain-cz-online}

\renewenvironment{thebibliography}[1]{%
  \bib@heading
  \ifx\bibpreamble\relax\else\ifx\bibpreamble\@empty\else
      \noindent\bibpreamble\par\nobreak
  \fi\fi
  \list{%
    \@biblabel{\@arabic\c@enumiv}%
  }{%
    \small
    \settowidth\labelwidth{\@biblabel{#1}}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \itemsep=0pt
    \@openbib@code
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \renewcommand*\theenumiv{\@arabic\c@enumiv}%
  }%
  \sloppy\clubpenalty4000 \widowpenalty4000
  \sfcode`\.=\@m
}{%
  \def\@noitemerr{%
    \@latex@warning{Empty `thebibliography' environment}%
  }%
  \endlist
}

%% Misc...
\def\CONTEXT{\texorpdfstring{Con\kern-.1em\TeX{}t}{ConTeXt}}
\def\MetaPost{\texorpdfstring{\MP}{MetaPost}}

\endinput

%% End of file `nrp-report.cls'
